<!--
SPDX-FileCopyrightText: 2014 Coraline Ada Ehmke
SPDX-FileCopyrightText: 2019-2021 Kattni Rembor for Adafruit Industries

SPDX-License-Identifier: CC-BY-4.0
-->
# Adafruit Community Code of Conduct

## Our Pledge

In the interest of fostering an open and welcoming environment, we as
contributors and leaders pledge to making participation in our project and
our community a harassment-free experience for everyone, regardless of age, body
size, disability, ethnicity, gender identity and expression, level or type of
experience, education, socio-economic status, nationality, personal appearance,
race, religion, or sexual identity and orientation.

## Our Standards

We are committed to providing a friendly, safe and welcoming environment for
all.

Examples of behavior that contributes to creating and maintaining a positive environment
include:

* Be kind and courteous to others
* Using welcoming and inclusive language
* Respecting the identity of every community member, including asking for their
  pronouns if uncertain
* Being respectful of differing viewpoints and experiences
* Collaborating with other community members
* Providing desired assistance and knowledge to other community members
* Being open to new information and ideas
* Gracefully accepting constructive criticism
* Focusing on what is best for the community
* Showing empathy towards other community members

Examples of unacceptable behavior by community members include:

* The use of sexualized language or imagery and sexual attention or advances
* The use of inappropriate images, including in a community member's avatar
* The use of inappropriate language or profanity, including in a community member's nickname
* Any spamming, flaming, baiting or other attention-stealing behavior
* Excessive or unwelcome helping; answering outside the scope of the question
  asked
* Discussion or promotion of activities or projects that intend or pose a risk of
  significant harm
* Trolling, insulting/derogatory comments, and attacks of any nature (including,
  but not limited to, personal or political attacks)
* Promoting or spreading disinformation, lies, or conspiracy theories against
  a person, group, organisation, project, or community
* Public or private harassment
* Publishing others' private information, such as a physical or electronic
  address, without explicit permission
* Engaging in behavior that creates an unwelcoming or uninclusive environment
* Other conduct which could reasonably be considered inappropriate

The Adafruit Community welcomes everyone and strives to create a safe space for all. It is built
around sharing and contributing to technology. We encourage discussing your thoughts, experiences,
and feelings within the scope of the community. However, there are topics that can sometimes stray
from that scope, and can lead to hurting others and create an unwelcoming, uninclusive environment.

Examples of discussion topics that have been known to stray outside the scope of the Adafruit
Community include, but are not limited to:

* Discussions regarding religion and related topics
* Discussions regarding politics and related topics

The goal of the standards and moderation guidelines outlined here is to build
and maintain a respectful community. We ask that you don’t just aim to be
"technically unimpeachable", but rather try to be your best self.

We value many things beyond technical expertise, including collaboration and
supporting others within our community. Providing a positive experience for
other community members can have a much more significant impact than simply
providing the correct answer.

## Our Responsibilities

Project leaders are responsible for clarifying the standards of acceptable
behavior and are expected to take appropriate and fair corrective action in
response to any instances of unacceptable behavior.

Project leaders have the right and responsibility to remove, edit, or
reject messages, comments, commits, code, issues, and other contributions
that are not aligned to this Code of Conduct, or to ban temporarily or
permanently any community member for other behaviors that they deem
inappropriate, threatening, offensive, or harmful.

## Moderation

Instances of behaviors that violate the Adafruit Community Code of Conduct
may be reported by any member of the community. Community members are
encouraged to report these situations, including situations they witness
involving other community members.

You may report in the following ways:

In any situation, you may email <support@adafruit.com>.

On the Adafruit Discord, you may send an open message from any channel
to all Community Moderators by tagging @community moderators. You may
also send an open message from the #help-with-community channel, or a
direct message to any Community Moderator.

The source of email and direct message reports will be kept confidential.

In situations on Discord where the issue is particularly offensive, possibly
illegal, requires immediate action, or violates the Discord terms of service,
you should also report the message directly to [Discord](https://discord.com/safety).

These are the steps for upholding our community’s standards of conduct.

1. Any member of the community may report any situation that violates the
   Adafruit Community Code of Conduct. All reports will be reviewed and
   investigated.
2. If the behavior is a severe violation, the community member who
   committed the violation may be banned immediately, without warning.
3. Otherwise, moderators will first respond to such behavior with a warning.
4. Moderators follow a soft "three strikes" policy - the community member may
   be given another chance, if they are receptive to the warning and change their
   behavior.
5. If the community member is unreceptive or unreasonable when warned by a
   moderator, or the warning goes unheeded, they may be banned for a first or
   second offense. Repeated offenses will result in the community member being
   banned.
6. Disciplinary actions (warnings, bans, etc) for Code of Conduct violations apply
   to the platform where the violation occurred. However, depending on the severity
   of the violation, the disciplinary action may be applied across Adafruit's other
   community platforms. For example, a severe violation on the Adafruit Discord
   server may result in a ban on not only the Adafruit Discord server, but also on
   the Adafruit GitHub organisation, Adafruit Forums, Adafruit Twitter, etc.

## Scope

This Code of Conduct and the enforcement policies listed above apply to all
Adafruit Community venues. This includes but is not limited to any community
spaces (both public and private), the entire Adafruit Discord server, and
Adafruit GitHub repositories. Examples of Adafruit Community spaces include
but are not limited to meet-ups, audio chats on the Adafruit Discord, or
interaction at a conference.

This Code of Conduct applies both within project spaces and in public spaces
when an individual is representing the project or its community. As a community
member, you are representing our community, and are expected to behave
accordingly.

## Attribution

This Code of Conduct is adapted from the [Contributor Covenant](https://www.contributor-covenant.org/),
version 1.4, available on [contributor-covenant.org](https://www.contributor-covenant.org/version/1/4/code-of-conduct.html),
and the [Rust Code of Conduct](https://www.rust-lang.org/en-US/conduct.html).

For other projects adopting the Adafruit Community Code of
Conduct, please contact the maintainers of those projects for enforcement.
If you wish to use this code of conduct for your own project, consider
explicitly mentioning your moderation policy or making a copy with your
own moderation policy so as to avoid confusion.
